@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2009 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2009-2010 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /**
@@ -96,7 +96,9 @@ gcm_calibrate_manual_close_cb (GtkWidget *widget, GcmCalibrateManual *calibrate)
 	/* we closed */
 	priv->ret = FALSE;
 	if (priv->error != NULL)
-		*(priv->error) = g_error_new (1, 0, "user closed window");
+		*(priv->error) = g_error_new (GCM_CALIBRATE_ERROR,
+					      GCM_CALIBRATE_ERROR_USER_ABORT,
+					      "user closed window");
 
 	/* we're done */
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "dialog_calibrate"));
@@ -188,6 +190,8 @@ gcm_calibrate_manual_setup_page (GcmCalibrateManual *calibrate, guint page)
 	gdouble ave;
 	gchar *title = NULL;
 	gdouble div;
+	GString *string_title = NULL;
+	GString *string_msg = NULL;
 	GcmCalibrateManualPrivate *priv = calibrate->priv;
 
 	if (page == GCM_CALIBRATE_MANUAL_PAGE_INTRO) {
@@ -210,17 +214,36 @@ gcm_calibrate_manual_setup_page (GcmCalibrateManual *calibrate, guint page)
 		gtk_widget_hide (widget);
 		widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "hbox_text1"));
 		gtk_widget_show (widget);
+
+		string_msg = g_string_new ("");
+		string_title = g_string_new ("");
+
+		/* TRANSLATORS: message text, an ICC profile is a file that characterizes the device */
+		g_string_append_printf (string_msg, "%s ", _("This dialog will help calibrate your display and create a custom ICC profile."));
+
+		/* TRANSLATORS: message text, telling the user they are in for the long haul */
+		g_string_append_printf (string_msg, "%s ", _("The calibration will involve several steps so that an accurate profile can be obtained."));
+
+		/* TRANSLATORS: message text, this is a lie. It will take more than a few minutes, but we don't want to scare the hapless user */
+		g_string_append_printf (string_msg, "%s", _("It should only take a few minutes."));
+
+		/* set the message */
 		widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "label_text1"));
-		/* TRANSLATORS: message text */
-		gtk_label_set_label (GTK_LABEL(widget), _("This dialog will calibrate your display and create a custom ICC profile. "
-							  "Display calibration will involve several steps so that an accurate profile can be obtained. "
-							  "It should only take a few minutes."));
+		gtk_label_set_label (GTK_LABEL(widget), string_msg->str);
+
 		widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "hbox_text2"));
 		gtk_widget_show (widget);
+
+		/* TRANSLATORS: message text, when you're comparing colors, it helps if the image is a bit out of focus otherwise the
+		 * fovea (center bit of the eye) tries to 'pick out' a colour, rather than take the average reading */
+		g_string_append_printf (string_title, "%s ", _("It may help to sit further from the screen or to squint at the calibration images in order to accurately compare the colors."));
+
+		/* TRANSLATORS: message text, tell the use that they can go back and forwards, as the human eye sucks */
+		g_string_append_printf (string_title, "%s", _("You can repeat the calibration steps as many times as you want."));
+
+		/* set the message */
 		widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "label_text2"));
-		/* TRANSLATORS: message text */
-		gtk_label_set_label (GTK_LABEL(widget), _("It may help to sit back from the screen or squint at the calibration widgets in order to accurately match the colors. "
-							  "You can also repeat the calibration steps as many times as you want."));
+		gtk_label_set_label (GTK_LABEL(widget), string_title->str);
 		goto out;
 	}
 
@@ -373,6 +396,10 @@ gcm_calibrate_manual_setup_page (GcmCalibrateManual *calibrate, guint page)
 
 	egg_warning ("oops - no page");
 out:
+	if (string_title != NULL)
+		g_string_free (string_title, TRUE);
+	if (string_msg != NULL)
+		g_string_free (string_msg, TRUE);
 	g_free (title);
 	priv->current_page = page;
 }
@@ -675,43 +702,3 @@ gcm_calibrate_manual_new (void)
 	return GCM_CALIBRATE_MANUAL (calibrate);
 }
 
-/***************************************************************************
- ***                          MAKE CHECK TESTS                           ***
- ***************************************************************************/
-#ifdef EGG_TEST
-#include "egg-test.h"
-
-void
-gcm_calibrate_manual_test (EggTest *test)
-{
-	GcmCalibrateManual *calibrate;
-	gboolean ret;
-	GError *error = NULL;
-
-	if (!egg_test_start (test, "GcmCalibrateManual"))
-		return;
-
-	/************************************************************/
-	egg_test_title (test, "get a calibrate_manual object");
-	calibrate = gcm_calibrate_manual_new ();
-	egg_test_assert (test, calibrate != NULL);
-
-	/* set to avoid a critical warning */
-	g_object_set (calibrate,
-		      "output-name", "lvds1",
-		      NULL);
-
-	/************************************************************/
-	egg_test_title (test, "calibrate display manually");
-	ret = gcm_calibrate_display (GCM_CALIBRATE(calibrate), NULL, &error);
-	if (ret)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "error: %s", error->message);
-
-	g_object_unref (calibrate);
-
-	egg_test_end (test);
-}
-#endif
-
