@@ -25,6 +25,7 @@
 #include <glib-object.h>
 
 #include "gcm-enum.h"
+#include "gcm-profile.h"
 
 G_BEGIN_DECLS
 
@@ -51,6 +52,7 @@ struct _GcmDeviceClass
 	void		 (*changed)			(GcmDevice		*device);
 	gboolean	 (*apply)			(GcmDevice		*device,
 							 GError			**error);
+	gchar		*(*get_config_data)		(GcmDevice		*device);
 	/* padding for future expansion */
 	void (*_gcm_reserved1) (void);
 	void (*_gcm_reserved2) (void);
@@ -107,11 +109,17 @@ void			 gcm_device_set_model			(GcmDevice	*device,
 const gchar		*gcm_device_get_title			(GcmDevice	*device);
 void			 gcm_device_set_title			(GcmDevice	*device,
 								 const gchar 	*title);
-const gchar		*gcm_device_get_profile_filename	(GcmDevice	*device);
-void			 gcm_device_set_profile_filename	(GcmDevice	*device,
-								 const gchar 	*profile_filename);
+GPtrArray		*gcm_device_get_profiles		(GcmDevice	*device);
+void			 gcm_device_set_profiles		(GcmDevice	*device,
+								 GPtrArray	*profiles);
 glong			 gcm_device_get_modified_time		(GcmDevice	*device);
 
+/* helpers */
+GcmProfile		*gcm_device_get_default_profile		(GcmDevice	*device);
+const gchar		*gcm_device_get_default_profile_filename (GcmDevice	*device);
+void			 gcm_device_set_default_profile_filename (GcmDevice	*device,
+								 const gchar 	*profile_filename);
+
 G_END_DECLS
 
 #endif /* __GCM_DEVICE_H */
