@@ -23,38 +23,99 @@
 
 #include <glib/gi18n.h>
 #include <locale.h>
-#include <lcms.h>
+#include <lcms2.h>
+
+static gint lcms_error_code = 0;
+
+/*
+ * _cmsWriteTagTextAscii:
+ */
+static cmsBool
+_cmsWriteTagTextAscii (cmsHPROFILE lcms_profile, cmsTagSignature sig, const gchar *text)
+{
+	cmsBool ret;
+	cmsMLU *mlu = cmsMLUalloc (0, 1);
+	cmsMLUsetASCII (mlu, "EN", "us", text);
+	ret = cmsWriteTag (lcms_profile, sig, mlu);
+	cmsMLUfree (mlu);
+	return ret;
+}
 
 /*
  * gcm_fix_profile_filename:
  */
-static void
+static gboolean
 gcm_fix_profile_filename (const gchar *filename, const gchar *description, const gchar *copyright, const gchar *model, const gchar *manufacturer)
 {
-	cmsHPROFILE lcms_profile;
-	lcms_profile = cmsOpenProfileFromFile (filename, "rw");
-	if (lcms_profile == NULL)
-		return;
-	if (description != NULL)
-		_cmsAddTextTag (lcms_profile, icSigProfileDescriptionTag, description);
-	if (copyright != NULL)
-		_cmsAddTextTag (lcms_profile, icSigCopyrightTag, copyright);
-	if (model != NULL)
-		_cmsAddTextTag (lcms_profile, icSigDeviceModelDescTag, model);
-	if (manufacturer != NULL)
-		_cmsAddTextTag (lcms_profile, icSigDeviceMfgDescTag, manufacturer);
-	_cmsSaveProfile (lcms_profile, filename);
-	cmsCloseProfile (lcms_profile);
+	gboolean ret = TRUE;
+	cmsHPROFILE lcms_profile = NULL;
+	gchar *data = NULL;
+	gsize len;
+	GError *error = NULL;
+
+	ret = g_file_get_contents (filename, &data, &len, &error);
+	if (!ret) {
+		g_warning ("failed to open profile: %s", error->message);
+		g_error_free (error);
+		goto out;
+	}
+
+	lcms_profile = cmsOpenProfileFromMem (data, len);
+	if (lcms_profile == NULL || lcms_error_code != 0) {
+		g_warning ("failed to open profile");
+		ret = FALSE;
+		goto out;
+	}
+
+	/* profile version to write */
+	cmsSetProfileVersion (lcms_profile, 3.4);
+	if (description != NULL) {
+		ret = _cmsWriteTagTextAscii (lcms_profile, cmsSigProfileDescriptionTag, description);
+		if (!ret || lcms_error_code != 0) {
+			g_warning ("failed to write description");
+			goto out;
+		}
+	}
+	if (copyright != NULL) {
+		ret = _cmsWriteTagTextAscii (lcms_profile, cmsSigCopyrightTag, copyright);
+		if (!ret || lcms_error_code != 0) {
+			g_warning ("failed to write copyright");
+			goto out;
+		}
+	}
+	if (model != NULL) {
+		ret = _cmsWriteTagTextAscii (lcms_profile, cmsSigDeviceModelDescTag, model);
+		if (!ret || lcms_error_code != 0) {
+			g_warning ("failed to write model");
+			goto out;
+		}
+	}
+	if (manufacturer != NULL) {
+		ret = _cmsWriteTagTextAscii (lcms_profile, cmsSigDeviceMfgDescTag, manufacturer);
+		if (!ret || lcms_error_code != 0) {
+			g_warning ("failed to write manufacturer");
+			goto out;
+		}
+	}
+
+	cmsSaveProfileToFile (lcms_profile, filename);
+out:
+	if (lcms_profile != NULL)
+		cmsCloseProfile (lcms_profile);
+	g_free (data);
+	return ret;
 }
 
-/*
- * gcm_fix_profile_lcms_error_cb:
- */
-static int
-gcm_fix_profile_lcms_error_cb (int ErrorCode, const char *ErrorText)
+/**
+ * gcm_fix_profile_error_cb:
+ **/
+static void
+gcm_fix_profile_error_cb (cmsContext ContextID, cmsUInt32Number errorcode, const char *text)
 {
-	g_warning ("LCMS error %i: %s", ErrorCode, ErrorText);
-	return LCMS_ERRC_WARNING;
+	g_warning ("LCMS error %i: %s", errorcode, text);
+
+	/* copy this sytemwide */
+	lcms_error_code = errorcode;
 }
 
 /*
@@ -65,6 +126,7 @@ main (int argc, char **argv)
 {
 	guint i;
 	guint retval = 0;
+	gboolean ret;
 	GOptionContext *context;
 	gchar **files = NULL;
 	gchar *description = NULL;
@@ -108,13 +170,16 @@ main (int argc, char **argv)
 		goto out;
 
 	/* setup LCMS */
-	cmsSetErrorHandler (gcm_fix_profile_lcms_error_cb);
-	cmsErrorAction (LCMS_ERROR_SHOW);
-	cmsSetLanguage ("en", "US");
+	cmsSetLogErrorHandler (gcm_fix_profile_error_cb);
 
-	/* show each profile */
-	for (i=0; files[i] != NULL; i++)
-		gcm_fix_profile_filename (files[i], description, copyright, model, manufacturer);
+	/* fix each profile */
+	for (i=0; files[i] != NULL; i++) {
+		ret = gcm_fix_profile_filename (files[i], description, copyright, model, manufacturer);
+		if (!ret) {
+			retval = 1;
+			goto out;
+		}
+	}
 out:
 	g_free (description);
 	g_free (copyright);
