@@ -24,7 +24,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <locale.h>
-#ifdef HAVE_LIBNOTIFY
+#ifdef HAVE_NOTIFY
 #include <libnotify/notify.h>
 #endif
 #include "egg-debug.h"
@@ -68,7 +68,7 @@ gcm_session_check_idle_cb (gpointer user_data)
 	return TRUE;
 }
 
-#ifdef HAVE_LIBNOTIFY
+#ifdef HAVE_NOTIFY
 /**
  * gcm_session_notify_cb:
  **/
@@ -246,32 +246,26 @@ out:
 }
 
 /**
- * gcm_session_get_profiles_for_kind:
+ * gcm_session_get_profiles_for_profile_kind:
  **/
 static GPtrArray *
-gcm_session_get_profiles_for_kind (GcmDeviceKind kind, GError **error)
+gcm_session_get_profiles_for_profile_kind (GcmProfileKind kind, GError **error)
 {
 	guint i;
 	GcmProfile *profile;
-	GcmProfileKind profile_kind;
-	GcmProfileKind kind_tmp;
 	GPtrArray *array;
 	GPtrArray *profile_array;
 
 	/* create a temp array */
 	array = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
 
-	/* get the correct profile kind for the device kind */
-	profile_kind = gcm_utils_device_kind_to_profile_kind (kind);
-
 	/* get list */
 	profile_array = gcm_profile_store_get_array (profile_store);
 	for (i=0; i<profile_array->len; i++) {
 		profile = g_ptr_array_index (profile_array, i);
 
 		/* compare what we have against what we were given */
-		kind_tmp = gcm_profile_get_kind (profile);
-		if (kind_tmp == profile_kind)
+		if (kind == gcm_profile_get_kind (profile))
 			g_ptr_array_add (array, g_object_ref (profile));
 	}
 
@@ -292,7 +286,7 @@ gcm_session_variant_from_profile_array (GPtrArray *array)
 	GVariant *value;
 
 	/* create builder */
-	builder = g_variant_builder_new (G_VARIANT_TYPE_ARRAY);
+	builder = g_variant_builder_new (G_VARIANT_TYPE("a(ss)"));
 
 	/* add each tuple to the array */
 	for (i=0; i<array->len; i++) {
@@ -437,6 +431,8 @@ gcm_session_handle_method_call (GDBusConnection *connection_, const gchar *sende
 	GcmDevice *device;
 	GError *error = NULL;
 	const gchar *profile_filename;
+	GcmProfileKind profile_kind;
+	GcmDeviceKind device_kind;
 	guint i;
 
 	/* return 'as' */
@@ -503,8 +499,24 @@ gcm_session_handle_method_call (GDBusConnection *connection_, const gchar *sende
 	if (g_strcmp0 (method_name, "GetProfilesForType") == 0) {
 		g_variant_get (parameters, "(ss)", &type, &hints);
 
+		/* try to parse string */
+		profile_kind = gcm_profile_kind_from_string (type);
+		if (profile_kind == GCM_PROFILE_KIND_UNKNOWN) {
+			/* get the correct profile kind for the device kind */
+			device_kind = gcm_device_kind_from_string (type);
+			profile_kind = gcm_utils_device_kind_to_profile_kind (device_kind);
+		}
+
+		/* still nothing */
+		if (profile_kind == GCM_PROFILE_KIND_UNKNOWN) {
+			g_dbus_method_invocation_return_dbus_error (invocation,
+								    "org.gnome.ColorManager.Failed",
+								    "did not get a profile or device type");
+			goto out;
+		}
+
 		/* get array of profiles */
-		array = gcm_session_get_profiles_for_kind (gcm_device_kind_from_string (type), &error);
+		array = gcm_session_get_profiles_for_profile_kind (profile_kind, &error);
 		if (array == NULL) {
 			g_dbus_method_invocation_return_dbus_error (invocation,
 								    "org.gnome.ColorManager.Failed",
@@ -732,6 +744,7 @@ main (int argc, char *argv[])
 
 	/* have access to all profiles */
 	profile_store = gcm_profile_store_new ();
+	gcm_profile_store_search (profile_store, GCM_PROFILE_STORE_SEARCH_ALL);
 	timer = g_timer_new ();
 
 	/* get all connected devices */
