@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2009 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2009-2010 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -56,9 +56,9 @@ struct _GcmXyzClass
 
 GType		 gcm_xyz_get_type		  	(void);
 GcmXyz		*gcm_xyz_new				(void);
-gfloat		 gcm_xyz_get_x				(GcmXyz		*xyz);
-gfloat		 gcm_xyz_get_y				(GcmXyz		*xyz);
-gfloat		 gcm_xyz_get_z				(GcmXyz		*xyz);
+gdouble		 gcm_xyz_get_x				(GcmXyz		*xyz);
+gdouble		 gcm_xyz_get_y				(GcmXyz		*xyz);
+gdouble		 gcm_xyz_get_z				(GcmXyz		*xyz);
 void		 gcm_xyz_print				(GcmXyz		*xyz);
 void		 gcm_xyz_clear				(GcmXyz		*xyz);
 
